summaryrefslogtreecommitdiffstats
path: root/ksayit/src/contextmenuhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksayit/src/contextmenuhandler.h')
-rw-r--r--ksayit/src/contextmenuhandler.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/ksayit/src/contextmenuhandler.h b/ksayit/src/contextmenuhandler.h
index 148bb04..88d7c0e 100644
--- a/ksayit/src/contextmenuhandler.h
+++ b/ksayit/src/contextmenuhandler.h
@@ -12,7 +12,7 @@
#ifndef CONTEXTMENUHANDLER_H
#define CONTEXTMENUHANDLER_H
-// Qt includes
+// TQt includes
#include <tqobject.h>
#include <tqstring.h>
#include <tqxml.h>
@@ -64,11 +64,12 @@ private:
/**
@author Robert Vogl
*/
-class ContextMenuHandler : public QObject
+class ContextMenuHandler : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- ContextMenuHandler(TQObject *parent = 0, const char *name = 0);
+ ContextMenuHandler(TQObject *tqparent = 0, const char *name = 0);
~ContextMenuHandler();
@@ -79,10 +80,10 @@ public:
KPopupMenu* getPopupMenu(ListViewInterface *item);
/**
* \returns A pointer to the Submenu as a child of the parent
* \p parent.
*/
- KPopupMenu* SubMenuFactory(KPopupMenu *parent);
+ KPopupMenu* SubMenuFactory(KPopupMenu *tqparent);
/**
* Creates an action sufficiant to the given name.
@@ -79,10 +80,10 @@ public:
KPopupMenu* getPopupMenu(ListViewInterface *item);
/**
- * \returns A pointer to the Submenu as a child of the parent
- * \p parent.
+ * \returns A pointer to the Submenu as a child of the tqparent
+ * \p tqparent.
*/